@@ -30,6 +30,7 @@
 #include "io.h"
 #include "atmd.h"
 #include "atm.h"
+#include "atmf_uni.h"
 
 #define SNMP_VCI 16
 #define COMPONENT "IO"
@@ -53,7 +54,13 @@ AsnOid *get_esi(int fd, int itf)
 
   if(ioctl(fd, ATM_GETESI, &req) < 0)
     diag(COMPONENT, DIAG_FATAL, "ioctl ATM_GETESI: %s", strerror(errno));
-  
+ 
+  /* save esi to atmfMySystemIdentifierValue */
+  if (!atmfMySystemIdentifierValue.octs) {
+     atmfMySystemIdentifierValue.octs = alloc(6);
+     memcpy(atmfMySystemIdentifierValue.octs, esi, 6);
+  }
+ 
   /* Convert hex string to Object ID BER */
   for(m = 0, size = 0; m < ESI_LEN; esi[m++] & 0x80 ? size += 2 : size++);
   size++;
