@@ -41,7 +41,7 @@
 /* Gets End System Identifier (MAC address) from kernel
  * Returns < 0 for error
  */
-int addr_getesi(unsigned char *mac_addr)
+int addr_getesi(unsigned char *mac_addr, int phys_itf)
 {
         int fd, retval;
         struct atmif_sioc req;
@@ -52,7 +52,7 @@ int addr_getesi(unsigned char *mac_addr)
                      strerror(errno));
                 return -1;
         }
-        req.number = 0;
+        req.number = phys_itf;
         req.arg = mac_addr;
         req.length = ESI_LEN;
         retval = ioctl(fd, ATM_GETESI, &req);
@@ -67,7 +67,7 @@ int addr_getesi(unsigned char *mac_addr)
  * Returns < 0 for error
  */
 #define MAX_LOCAL_ADDRS 32
-int get_listenaddr(unsigned char *atm_addr)
+int get_listenaddr(unsigned char *atm_addr, int phys_itf)
 {
         int fd, retval;
         struct atmif_sioc req;
@@ -79,7 +79,7 @@ int get_listenaddr(unsigned char *atm_addr)
                      strerror(errno));
                 return -1;
         }
-        req.number = 0;
+        req.number = phys_itf;
         req.arg = listen_addr;
         req.length = sizeof(listen_addr);
         retval = ioctl(fd, ATM_GETADDR, &req);
