@@ -64,6 +64,7 @@ static void usage(const char *progname)
 {
   printf("Usage: %s [-c LECS_address | -s LES_address] [-e esi] [-n VLAN_name]"
     " [-m mesg_mask] [-l listen_address | selector] [-i interface_number]"
+    " [-I physical_interface_number]"
     " [-t 1516|1580|4544|9234|18190] [-1] [-2] [-p] [-F logfile]"
     " [-f Fore specific name]\n", progname);
 }
@@ -165,6 +166,7 @@ static int config_kernel(void)
         msg.content.config.path_switching_delay = lec_params.c22_path_switching_delay;
         msg.content.config.lane_version = (lec_params.c29_v2_capable) ? 2 : 1;
 	msg.content.config.mtu = maxmtu2itfmtu(lec_params.c3_max_frame_size);
+	msg.content.config.is_proxy = lec_params.c4_proxy_flag;
 
         if (msg_to_kernel(&msg, sizeof(struct atmlec_msg)) < 0) {
                 diag(COMPONENT, DIAG_ERROR, "Could not tell kernel ELAN parameters\n");
@@ -188,7 +190,7 @@ int main(int argc, char **argv)
         int lane_version = 0;              /* LANE2 */
         int max_frame_size = MTU_UNSPEC;
         int lecs_method = LECS_WELLKNOWN;
-        int poll_ret = 0, itf = 0, selector = 0;
+        int poll_ret = 0, itf = 0, phys_itf = 0, selector = 0;
         struct sockaddr_atmsvc manual_atm_addr;
         struct sockaddr_atmsvc listen_addr;
         
@@ -200,13 +202,8 @@ int main(int argc, char **argv)
 
         set_application("zeppelin"); /* for debug msgs */
 
-        if (get_listenaddr(listen_addr.sas_addr.prv) < 0) {
-                diag(COMPONENT, DIAG_FATAL, "Could not figure out my ATM address\n");
-                exit(-1);
-        }
-
         while(poll_ret != -1) {
-                poll_ret = getopt(argc, argv, "c:e:n:s:m:l:i:q:12pf:t:F:");
+                poll_ret = getopt(argc, argv, "c:e:n:s:m:l:i:I:q:12pf:t:F:");
                 switch(poll_ret) {
                 case 'c':
                         if (atm_set) {
@@ -292,6 +289,14 @@ int main(int argc, char **argv)
                         }
                         diag(COMPONENT, DIAG_INFO, "Interface number set to %d\n", itf);
                         break;
+                case 'I':
+                        if (sscanf(optarg, "%d", &phys_itf) <= 0 || phys_itf < 0) {
+                                diag(COMPONENT, DIAG_ERROR, "Invalid physical interface number\n");
+                                usage(argv[0]);
+                                exit(-1);
+                        }
+                        diag(COMPONENT, DIAG_INFO, "Physical interface number set to %d\n", phys_itf);
+                        break;
                 case 'q':
 #if 0
                         if (text2qos(optarg,NULL,0) < 0) {
@@ -351,8 +356,13 @@ int main(int argc, char **argv)
         /* Reserve signals */
         signal(SIGHUP, sig_reset);
 
+        if (get_listenaddr(listen_addr.sas_addr.prv, phys_itf) < 0) {
+                diag(COMPONENT, DIAG_FATAL, "Could not figure out my ATM address\n");
+                exit(-1);
+        }
+
         if (!esi_set) {
-                if(addr_getesi(mac_addr) < 0) {
+                if(addr_getesi(mac_addr, phys_itf) < 0) {
                         diag(COMPONENT, DIAG_ERROR, "Can't get ESI from kernel!\n");
                         return -1;
                 }
