@@ -1,6 +1,6 @@
 /* ans.c - Interface for text2atm and atm2text to ANS */
 
-/* Written 1996,1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1996-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 /*
@@ -83,6 +83,12 @@ static int ans(const char *text,int wanted,void *result,int res_len)
 	if (GET16(data-10) != wanted || GET16(data-8) != C_IN || !--data_len)
 	    continue;
 	switch (wanted) {
+            case T_NSAP:
+                data_len++;
+                if (data_len != ATM_ESA_LEN) continue;
+                memcpy(((struct sockaddr_atmsvc *) result)->
+                  sas_addr.prv,data,ATM_ESA_LEN);
+                return 0;
 	    case T_ATMA:
 		switch (*data++) {
 		    case ATMA_AESA:
@@ -122,7 +128,8 @@ int ans_byname(const char *text,struct sockaddr_atmsvc *addr,int length,
     if (!(flags & T2A_SVC) || length != sizeof(*addr)) return TRY_OTHER; 
     memset(addr,0,sizeof(*addr));
     addr->sas_family = AF_ATMSVC;
-    return ans(text,T_ATMA,addr,length);
+    if (!ans(text,T_ATMA,addr,length)) return 0;
+    return ans(text,T_NSAP,addr,length);
 }
 
 
@@ -163,6 +170,25 @@ static int encode_nsap(char *buf,const unsigned char *addr)
 }
 
 
+static int encode_nsap_new(char *buf,const unsigned char *addr)
+{
+    int i;
+    int digit;
+
+    for (i = 20; i; ) {
+        i--;
+        digit = addr[i] & 0x0F;
+        *(buf++) = digit + (digit >= 10 ? '7' : '0');
+        *(buf++) = '.';
+        digit = ((unsigned char) (addr[i])) >> 4;
+        *(buf++) = digit + (digit >= 10 ? '7' : '0');
+        *(buf++) = '.';
+    }
+    strcpy (buf, "NSAP.INT.");
+    return 0;
+}
+
+
 static int cc_len(int p0,int p1)
 {
     static char *cc_table = NULL;
@@ -218,8 +244,15 @@ int ans_byaddr(char *buffer,int length,const struct sockaddr_atmsvc *addr,
     char tmp[MAX_NAME]; /* could be smaller ... */
     int res;
 
-    if (addr->sas_addr.prv) res = encode_nsap(tmp,addr->sas_addr.prv);
-    else res = encode_e164(tmp,addr->sas_addr.pub);
-    if (res < 0) return res;
-    return ans(tmp,T_PTR,buffer,length);
+    if (addr->sas_addr.prv) {
+        res = encode_nsap(tmp,addr->sas_addr.prv);
+        if (!res && !ans(tmp,T_PTR,buffer,length)) return 0;
+	res = encode_nsap_new(tmp,addr->sas_addr.prv);
+        if (res < 0) return res;
+	return ans(tmp,T_PTR,buffer,length);
+    } else {
+        res = encode_e164(tmp,addr->sas_addr.pub);
+        if (res < 0) return res;
+        return ans(tmp,T_PTR,buffer,length);
+    }
 }
