@@ -571,7 +571,8 @@ void from_kernel(struct atmsvc_msg *msg,int size)
 	    if (msg->vcc == curr->id) break;
     }
     diag(COMPONENT,DIAG_DEBUG,"FROM KERNEL: %s for socket %p (0x%lx/0x%lx) "
-      "in state %s",as_name[msg->type],curr,msg->vcc,msg->listen_vcc,
+      "in state %s",as_name[msg->type],curr,(unsigned long) msg->vcc,
+      (unsigned long) msg->listen_vcc,
       state_name[curr ? curr->state : ss_null]);
     dispatcher(curr,msg);
 }
