@@ -64,7 +64,7 @@ SOCKET *sockets = NULL;
 unsigned char q_buffer[MAX_Q_MSG];
 
 
-SOCKET *new_sock(unsigned long id)
+SOCKET *new_sock(atm_kptr_int_t id)
 {
     SOCKET *sock;
  
@@ -92,20 +92,22 @@ void free_sock(SOCKET *sock)
 {
     SOCKET **walk;
 
-    diag(COMPONENT,DIAG_DEBUG,"freeing socket 0x%lx@%p",sock->id,sock);
+    diag(COMPONENT,DIAG_DEBUG,"freeing socket 0x%lx@%p",
+      (unsigned long) sock->id,sock);
     for (walk = &sockets; *walk != sock; walk = &(*walk)->next);
     if (!*walk)
 	diag(COMPONENT,DIAG_FATAL,
-	  "INTERNAL ERROR: freeing non-existing socket 0x%lx",sock->id);
+	  "INTERNAL ERROR: freeing non-existing socket 0x%lx",
+	  (unsigned long) sock->id);
     *walk = sock->next;
     if (sock->conn_timer) {
 	diag(COMPONENT,DIAG_ERROR,"socket 0x%lx has timer (%p) running",
-	  sock->id,sock->conn_timer->callback);
+	  (unsigned long) sock->id,sock->conn_timer->callback);
 	stop_timer(sock->conn_timer);
     }
     if (sock->listen)
         diag(COMPONENT,DIAG_ERROR,"socket 0x%lx has non-empty listen queue",
-	  sock->id);
+	  (unsigned long) sock->id);
     sock->state = ss_invalid;
     free(sock);
 }
@@ -114,7 +116,7 @@ void free_sock(SOCKET *sock)
 void new_state(SOCKET *sock,STATE state)
 {
     diag(COMPONENT,DIAG_DEBUG,"socket 0x%lx enters state %s (UNI %s)",
-      sock->id,state_name[state],cs_name[state_map[state]]);
+      (unsigned long) sock->id,state_name[state],cs_name[state_map[state]]);
     sock->state = state;
     sock->call_state = state_map[state];
 }
@@ -203,7 +205,7 @@ const char *mid2name(unsigned char mid)
 }
 
 
-void send_kernel(unsigned long vcc,unsigned long listen_vcc,
+void send_kernel(atm_kptr_int_t vcc,atm_kptr_int_t listen_vcc,
   enum atmsvc_msg_type type,int reply,const struct sockaddr_atmpvc *pvc,
   const struct sockaddr_atmsvc *svc,const struct sockaddr_atmsvc *local,
   const struct atm_sap *sap,const struct atm_qos *qos)
