@@ -1,6 +1,6 @@
 /* timeout.c - Processing of signaling timeout events */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
  
 
 #include <stdio.h>
@@ -29,7 +29,7 @@ void on_T303(void *user) /* CONNECTING */
 {
     SOCKET *sock = user;
 
-    diag(COMPONENT,DIAG_DEBUG,"T303 on 0x%lx",sock->id);
+    diag(COMPONENT,DIAG_DEBUG,"T303 on 0x%lx",(unsigned long) sock->id);
     if (sock->state != ss_connecting) complain(sock,"T303");
     SEND_ERROR(sock->id,-ETIMEDOUT);
     sock->conn_timer = NULL;
@@ -41,7 +41,7 @@ void on_T308_1(void *user) /* WAIT_REL or REL_REQ */
 {
     SOCKET *sock = user;
 
-    diag(COMPONENT,DIAG_DEBUG,"T308_1 on 0x%lx",sock->id);
+    diag(COMPONENT,DIAG_DEBUG,"T308_1 on 0x%lx",(unsigned long) sock->id);
     if (sock->state != ss_wait_rel && sock->state != ss_rel_req)
 	complain(sock,"T308_1");
     send_release(sock,ATM_CV_TIMER_EXP,308); /* @@@ ? */
@@ -81,7 +81,7 @@ void on_T313(void *user) /* ACCEPTING */
 {
     SOCKET *sock = user;
 
-    diag(COMPONENT,DIAG_DEBUG,"T313 on 0x%lx",sock->id);
+    diag(COMPONENT,DIAG_DEBUG,"T313 on 0x%lx",(unsigned long) sock->id);
     if (sock->state != ss_accepting) complain(sock,"T313");
     send_release(sock,ATM_CV_TIMER_EXP,313);
     sock->conn_timer = NULL;
@@ -96,7 +96,7 @@ void on_T360(void *user)
 {
     SOCKET *sock = user;
 
-    diag(COMPONENT,DIAG_DEBUG,"T360 on 0x%lx",sock->id);
+    diag(COMPONENT,DIAG_DEBUG,"T360 on 0x%lx",(unsigned long) sock->id);
     if (sock->state != ss_mod_req) complain(sock,"T360");
     send_release(sock,ATM_CV_TIMER_EXP,360);
     sock->conn_timer = NULL;
@@ -109,7 +109,7 @@ void on_T361(void *user)
 {
     SOCKET *sock = user;
 
-    diag(COMPONENT,DIAG_DEBUG,"T361 on 0x%lx",sock->id);
+    diag(COMPONENT,DIAG_DEBUG,"T361 on 0x%lx",(unsigned long) sock->id);
     if (sock->state != ss_connected) complain(sock,"T361");
     sock->qos = sock->new_qos;
     send_kernel(sock->id,0,as_modify,ATM_MF_SET,NULL,NULL,NULL,NULL,&sock->qos);
