@@ -243,14 +243,15 @@ static void send_connect_ack(SOCKET *sock)
 }
 
 
-static void send_restart_ack(SIG_ENTITY *sig,int vpi,int vci)
+static void send_restart_ack(SIG_ENTITY *sig,unsigned long call_ref,int vpi,
+  int vci)
 {
     Q_DSC dsc;
     int size;
 
     q_create(&dsc,q_buffer,MAX_Q_MSG);
     q_assign(&dsc,QF_msg_type,ATM_MSG_REST_ACK);
-    q_assign(&dsc,QF_call_ref,0);
+    q_assign(&dsc,QF_call_ref,call_ref);
     if (!vpi && !vci) q_assign(&dsc,QF_rst_class,ATM_RST_ALL_VC);
     else {
 	q_assign(&dsc,QF_rst_class,ATM_RST_IND_VC);
@@ -387,7 +388,8 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 	    if (atm2text(buffer,MAX_ATM_ADDR_LEN+1,(struct sockaddr *)
 	      &sock->remote,0) < 0) strcpy(buffer,"<invalid>");
 	    diag(COMPONENT,DIAG_INFO,"Active open succeeded (CR 0x%06X, "
-	      "ID 0x%08x, to %s)",sock->call_ref,sock->id,buffer);
+	      "ID 0x%08lx, to %s)",sock->call_ref,(unsigned long) sock->id,
+	      buffer);
 	    return;
 	case ATM_MSG_CONN_ACK: /* ACCEPTING, WAIT_REL, REL_REQ */
 	    diag(COMPONENT,DIAG_DEBUG,"CA vpi.vci=%d.%d",
@@ -408,7 +410,8 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 	    if (atm2text(buffer,MAX_ATM_ADDR_LEN+1, (struct sockaddr *)
 	      &sock->remote,0) < 0) strcpy(buffer,"<invalid>");
 	    diag(COMPONENT,DIAG_INFO,"Passive open succeeded (CR 0x%06X, "
-	      "ID 0x%08x, from %s)",sock->call_ref,sock->id,buffer);
+	      "ID 0x%08lx, from %s)",sock->call_ref,(unsigned long) sock->id,
+	      buffer);
 	    return;
 	case ATM_MSG_RELEASE: /* all states */
 	    {
@@ -605,7 +608,7 @@ static void uni_call(SOCKET *sock,unsigned char mid)
 	    return;
 	case ATM_MSG_CONN_AVAIL:
 	    if (!(sock->sig->uni & S_Q2963_1)) goto _default;
-	    if (sock->state != ss_connected || !sock->owner) break;
+	    if (sock->state != ss_connected || sock->owner) break;
 	    STOP_TIMER(sock);
 	    send_kernel(sock->id,0,as_modify,ATM_MF_SET,NULL,NULL,NULL,NULL,
 	      &sock->qos);
@@ -714,7 +717,7 @@ static void process_uni(SIG_ENTITY *sig,void *msg)
 		    int vpi,vci;
 
 		    if (!q_present(&in_dsc,QG_conn_id)) {
-			send_status(sig,NULL,0L,ATM_CV_MAND_IE_MISSING,
+			send_status(sig,NULL,call_ref,ATM_CV_MAND_IE_MISSING,
 			  ATM_IE_CONN_ID);
 			return;
 		    }
@@ -724,20 +727,20 @@ static void process_uni(SIG_ENTITY *sig,void *msg)
 			if (curr->sig == sig && curr->pvc.sap_addr.vpi == vpi &&
 			  curr->pvc.sap_addr.vci == vci) break;
 		    if (!curr) {
-			send_status(sig,NULL,0L,ATM_CV_INVALID_IE,
+			send_status(sig,NULL,call_ref,ATM_CV_INVALID_IE,
 			  ATM_IE_CONN_ID);
 			return;
 		    }
 		    uni_call(curr,mid);
-		    send_restart_ack(sig,vpi,vci);
+		    send_restart_ack(sig,call_ref,vpi,vci);
 		}
 		break;
 	    case ATM_RST_ALL_VC:
 		clear_all_calls(sig);
-		send_restart_ack(sig,0,0);
+		send_restart_ack(sig,call_ref,0,0);
 		break;
 	    default:
-		send_status(sig,NULL,0L,ATM_CV_INVALID_IE,ATM_IE_RESTART);
+		send_status(sig,NULL,call_ref,ATM_CV_INVALID_IE,ATM_IE_RESTART);
 	}
 	return;
     }
@@ -749,7 +752,7 @@ static void process_uni(SIG_ENTITY *sig,void *msg)
 	if (curr->sig == sig && curr->call_ref == call_ref) break;
     diag(COMPONENT,DIAG_DEBUG,"FROM SAAL %d.%d.%d: %s (0x%02X) CR 0x%06lx for "
       "0x%lx",S_PVC(sig),mid2name(((unsigned char *) msg)[5]),
-      ((unsigned char *)msg)[5],call_ref,curr ? curr->id : 0);
+      ((unsigned char *)msg)[5],call_ref,curr ? (unsigned long) curr->id : 0UL);
     if (mid == ATM_MSG_SETUP) {
 	if (!curr) setup_call(sig,call_ref);
 	return;
