@@ -62,7 +62,6 @@ static char RCSid[] = "ttcp.c $Revision: 1.12 $";
 #include <sys/time.h>		/* struct timeval */
 #include <atm.h>
 #include <atmsap.h>
-#include <arequipa.h>
 
 #if defined(SYSV)
 #include <sys/times.h>
@@ -93,9 +92,7 @@ int bufalign = 16*1024;		/* modulo this */
 
 int atm = 0;			/* 0 = INET, !0 = ATM */
 int pcr = 0;
-int arequipa = 0;
 char *qos_spec = NULL;
-char *aq_host;
 
 int udp = 0;			/* 0 = tcp, !0 = udp */
 int options = 0;		/* socket options */
@@ -144,12 +141,9 @@ Options specific to -t:\n\
 	-C	disable (UDP) checksums\n\
 	-P X	use the specified QOS for the ATM connection. If X is only\n\
 		a number, the following QOS spec is assumed: cbr:pcr=X\n\
-	-Q X	establish an Arequipa connection to ATM destination X\n\
 Options specific to -r:\n\
 	-B	for -s, only output full blocks as specified by -l (for TAR)\n\
 	-T	\"touch\": access each byte as it's read\n\
-	-Q X	enable acceptance of incoming Arequipa connections\n\
-		X can be any word.\n\
 ";	
 
 char stats[128];
@@ -195,13 +189,9 @@ int no_check = 0;
 
     if (argc < 2) goto usage;
 
-    while ((c = getopt(argc, argv, "Q:adrstuvBDTb:f:l:n:p:P:A:O:C")) != -1) {
+    while ((c = getopt(argc, argv, "adrstuvBDTb:f:l:n:p:P:A:O:C")) != -1) {
 	switch (c) {
 
-	  case 'Q':
-	    arequipa = 1;
-	    aq_host = optarg;
-	    break;
 	  case 'a':
 	    atm = udp = 1;
 	    break;
@@ -291,23 +281,19 @@ int no_check = 0;
 	}     
 
     host = argv[optind];
-    if (atm && arequipa) {
-	fprintf(stderr,"-Q must not be used with -a\n");
-	return 1;
-    }
 
-    if (atm || (arequipa && trans)) {
+    if (atm) {
 	char *end;
 
 	memset(&satm,0,sizeof(satm));
 	if (!host) satm.sas_family = AF_ATMSVC;
-	else if (text2atm(atm ? host : aq_host,(struct sockaddr *) &satm,
+	else if (text2atm(host,(struct sockaddr *) &satm,
 	      sizeof(satm),T2A_PVC | T2A_SVC | T2A_NAME) < 0) {
 		fprintf(stderr,"invalid ATM address (PVC or SVC expected)\n");
 		exit(1);
 	    }
 	memset(&qos,0,sizeof(qos));
-	if (!arequipa) qos.rxtp.max_sdu = qos.txtp.max_sdu = buflen;
+	qos.rxtp.max_sdu = qos.txtp.max_sdu = buflen;
 	if (qos_spec && ((pcr = strtol(qos_spec,&end,10)), *end)) {
 	    if (text2qos(qos_spec,&qos,T2Q_DEFAULTS) < 0) {
 		fprintf(stderr,"invalid QOS specification\n");
@@ -323,7 +309,6 @@ int no_check = 0;
 		    qos.txtp.max_pcr = pcr;
 		}
 	}
-	if (arequipa && !udp) qos.rxtp = qos.txtp;
 	if (!qos.aal) qos.aal = ATM_AAL5;
     }
     if (!atm && trans)  {
@@ -393,10 +378,6 @@ int no_check = 0;
         udp?SOCK_DGRAM:SOCK_STREAM,0)) < 0) err("socket");
     
     mes("socket");
-    if (arequipa && trans) {
-	if (arequipa_preset(fd,&satm,&qos) < 0)
-	    err("arequipa_preset");
-    }
     if (atm) {
 	if (setsockopt(fd,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0)
 	    err("setsockopt SO_ATMQOS");
@@ -449,10 +430,7 @@ int no_check = 0;
 	  sizeof(sinme)) < 0)
 	    err("bind");
 
-    if (arequipa && !trans && !udp)
-	if (arequipa_expect(fd,1) < 0) err("arequipa_expect");
-
-    if (!udp || arequipa || (atm && satm.sas_family == AF_ATMSVC)) {
+    if (!udp || (atm && satm.sas_family == AF_ATMSVC)) {
 	signal(SIGPIPE, sigpipe);
 	if (trans) {
 	    /* We are the client if transmitting */
@@ -481,7 +459,7 @@ int no_check = 0;
 	    }
 	    if (atm) sleep(1); /* grr ... */
 #endif
-	} else if (!arequipa || !udp) {
+	} else {
 	    /* otherwise, we are the server and 
 	     * should listen for the connections
 	     */
@@ -1008,7 +986,7 @@ int count;
     
     if (udp)  {
       again:
-	if (atm || arequipa) cnt = write(fd, buf, count);
+	if (atm) cnt = write(fd, buf, count);
 	else cnt = sendto(fd, buf, count, 0, &sinhim, sizeof(sinhim));
 	numCalls++;
 	if ( cnt<0 && errno == ENOBUFS )  {
